import type { ServerDefinition } from '../config.js';
export declare function findServerByHttpUrl(definitions: readonly ServerDefinition[], urlString: string): string | undefined;
//# sourceMappingURL=server-lookup.d.ts.map