export type ConnectionIssueKind = 'auth' | 'offline' | 'http' | 'stdio-exit' | 'other';
export interface ConnectionIssue {
    kind: ConnectionIssueKind;
    rawMessage: string;
    statusCode?: number;
    stdioExitCode?: number;
    stdioSignal?: string;
}
export declare function analyzeConnectionError(error: unknown): ConnectionIssue;
export declare function isAuthIssue(issue: ConnectionIssue): boolean;
//# sourceMappingURL=error-classifier.d.ts.map