import type { CallResult } from '../result-utils.js';
export type OutputFormat = 'auto' | 'text' | 'markdown' | 'json' | 'raw';
export declare function printCallOutput<T>(wrapped: CallResult<T>, raw: T, format: OutputFormat): void;
export declare function tailLogIfRequested(result: unknown, enabled: boolean): void;
//# sourceMappingURL=output-utils.d.ts.map