export declare function readJsonFile<T = unknown>(filePath: string): Promise<T | undefined>;
export declare function writeJsonFile(filePath: string, data: unknown): Promise<void>;
//# sourceMappingURL=fs-json.d.ts.map