import type { Runtime } from '../runtime.js';
import { type ToolMetadata } from './generate/tools.js';
interface LoadToolMetadataOptions {
    includeSchema?: boolean;
    autoAuthorize?: boolean;
}
export declare function loadToolMetadata(runtime: Runtime, serverName: string, options?: LoadToolMetadataOptions): Promise<ToolMetadata[]>;
export {};
//# sourceMappingURL=tool-cache.d.ts.map