import type { EphemeralServerSpec } from './adhoc-server.js';
import type { OutputFormat } from './output-utils.js';
export interface CallArgsParseResult {
    selector?: string;
    server?: string;
    tool?: string;
    args: Record<string, unknown>;
    positionalArgs?: unknown[];
    tailLog: boolean;
    output: OutputFormat;
    timeoutMs?: number;
    ephemeral?: EphemeralServerSpec;
}
export declare function parseCallArguments(args: string[]): CallArgsParseResult;
//# sourceMappingURL=call-arguments.d.ts.map