import type { ConfigCliOptions } from './types.js';
export interface ImportFlags {
    path?: string;
    filter?: string;
    copy?: boolean;
    format: 'text' | 'json';
}
export declare function handleImportCommand(options: ConfigCliOptions, args: string[]): Promise<void>;
//# sourceMappingURL=import.d.ts.map