import type { ServerDefinition } from '../config.js';
type CommandResult = {
    kind: 'command';
    command: string;
    args: string[];
} | {
    kind: 'abort';
    exitCode: number;
};
export declare function inferCommandRouting(token: string, args: string[], definitions: readonly ServerDefinition[]): CommandResult;
export {};
//# sourceMappingURL=command-inference.d.ts.map