import type { EphemeralServerSpec } from './adhoc-server.js';
export declare function extractListFlags(args: string[]): {
    schema: boolean;
    timeoutMs?: number;
    requiredOnly: boolean;
    ephemeral?: EphemeralServerSpec;
    format: ListOutputFormat;
    verbose: boolean;
    includeSources: boolean;
};
type ListOutputFormat = 'text' | 'json';
export declare function handleList(runtime: Awaited<ReturnType<typeof import('../runtime.js')['createRuntime']>>, args: string[]): Promise<void>;
export declare function printListHelp(): void;
export {};
//# sourceMappingURL=list-command.d.ts.map