export declare function resolveRuntimeKind(runtimeOption: 'node' | 'bun' | undefined, compileOption: boolean | string | undefined): Promise<'node' | 'bun'>;
export declare function verifyBunAvailable(): Promise<string>;
//# sourceMappingURL=runtime.d.ts.map