import { resolveWriteTarget } from './config/add.js';
import type { ConfigCliOptions } from './config/types.js';
export declare function handleConfigCli(options: ConfigCliOptions, args: string[]): Promise<void>;
export declare const __configCommandInternals: {
    resolveWriteTarget: typeof resolveWriteTarget;
};
//# sourceMappingURL=config-command.d.ts.map