export declare function bundleOutput({ sourcePath, targetPath, runtimeKind, minify, bundler, }: {
    sourcePath: string;
    targetPath: string;
    runtimeKind: 'node' | 'bun';
    minify: boolean;
    bundler: 'rolldown' | 'bun';
}): Promise<string>;
export declare function compileBundleWithBun(bundlePath: string, outputPath: string): Promise<void>;
export declare function resolveBundleTarget({ bundle, compile, outputPath, }: {
    bundle?: boolean | string;
    compile?: boolean | string;
    outputPath: string;
}): string;
export declare function computeCompileTarget(compileOption: boolean | string | undefined, _bundlePath: string, serverName: string): string;
//# sourceMappingURL=artifacts.d.ts.map