import type { CliArtifactMetadata } from '../../cli-metadata.js';
import { type GenerateCliOptions } from '../../generate-cli.js';
export declare function performGenerateFromArtifact(metadata: CliArtifactMetadata, request: GenerateCliOptions): Promise<void>;
export declare function performGenerateFromRequest(request: GenerateCliOptions): Promise<void>;
//# sourceMappingURL=output.d.ts.map