import type { GeneratedOption } from './generate/tools.js';
export declare function buildDocComment(description: string | undefined, options: GeneratedOption[], opts?: {
    colorize?: boolean;
}): string[] | undefined;
export declare function wrapCommentText(text: string, width?: number): string[];
//# sourceMappingURL=list-doc-comments.d.ts.map