import type { ServerDefinition } from '../config.js';
import type { ToolDocModel } from './list-detail-helpers.js';
export interface ToolDocEntry {
    toolName: string;
    methodName: string;
    doc: ToolDocModel;
}
export interface EmitMetadata {
    server: ServerDefinition;
    generatorLabel: string;
    generatedAt: Date;
}
export interface EmitTypesTemplateInput {
    interfaceName: string;
    docs: ToolDocEntry[];
    metadata: EmitMetadata;
}
export interface EmitClientTemplateInput extends EmitTypesTemplateInput {
    typesImportPath: string;
}
export declare function renderTypesModule(input: EmitTypesTemplateInput): string;
export declare function renderClientModule(input: EmitClientTemplateInput): string;
//# sourceMappingURL=emit-ts-templates.d.ts.map