export type IdentifierResolution = {
    kind: 'auto';
    value: string;
} | {
    kind: 'suggest';
    value: string;
};
export declare function chooseClosestIdentifier(input: string, candidates: string[]): IdentifierResolution | undefined;
export declare function normalizeIdentifier(value: string): string;
export interface IdentifierResolutionContext {
    entity: 'server' | 'tool';
    attempted: string;
    resolution: IdentifierResolution;
    scope?: string;
}
export declare function renderIdentifierResolutionMessages(context: IdentifierResolutionContext): {
    auto?: string;
    suggest?: string;
};
//# sourceMappingURL=identifier-helpers.d.ts.map