import { type Logger, type LogLevel } from '../logging.js';
export declare function getActiveLogLevel(): LogLevel;
export declare function getActiveLogger(): Logger;
export declare function setLogLevel(level: LogLevel): void;
export declare function setLogger(logger: Logger, level?: LogLevel): void;
export declare function logInfo(message: string): void;
export declare function logWarn(message: string): void;
export declare function logError(message: string, error?: unknown): void;
//# sourceMappingURL=logger-context.d.ts.map